/*
 * Created on Jan 23, 2004
 */
package edu.umd.cs.daveho.eclipse.autocvs;

import java.util.Iterator;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.part.ViewPart;

/**
 * The AutoCVSLogView displays a log of AutoCVS actions
 * and diagnostics.
 * @author David Hovemeyer
 */
public class AutoCVSLogView extends ViewPart {
	private Text text;

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createPartControl(Composite parent) {
		text = new Text(parent, SWT.BORDER|SWT.H_SCROLL|SWT.V_SCROLL);
		text.setEditable(false);
		text.append("AutoCVS messages\n");
		
		// Append any existing events
		List oldEvents = AutoCVSPlugin.getPlugin().getEventLog().getAllEvents();
		for (Iterator i = oldEvents.iterator(); i.hasNext();) {
			Event element = (Event) i.next();
			appendEvent(element);
		}
		AutoCVSPlugin.getPlugin().getEventLog().purge();
		
		// Install a listener for log events
		EventLog.Listener listener = new EventLog.Listener() {
			public void logEvent(final Event event) {
				// We don't know where we're going to get called
				// from, so update the text control using asyncExec().
				Display.getDefault().asyncExec(new Runnable() {
					public void run() {
						// Show the event in the text control
						appendEvent(event);
						
						// Clean up old events
						AutoCVSPlugin.getPlugin().getEventLog().purge();
					}
				});
			}
		};
		AutoCVSPlugin.getPlugin().getEventLog().addListener(listener);
	}

	/**
	 * Append messages for an event to the text control.
	 * @param event the event
	 */
	private void appendEvent(Event event) {
		text.append("[" + event.getDate().toString() + "] ");
		if (event.isError())
			text.append("Error: ");
		text.append(event.getMessage() + "\n");
		Throwable e = event.getException();
		if (e != null) {
			text.append(e.toString());
			StackTraceElement[] traceList = e.getStackTrace();
			for (int i = 0; i < traceList.length; i++) {
				text.append("\t" + traceList[i].toString() + "\n");
			}
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchPart#setFocus()
	 */
	public void setFocus() {
		// TODO Auto-generated method stub

	}

}
