/*
 * Created on Jan 23, 2004
 */
package edu.umd.cs.daveho.eclipse.autocvs;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

/**
 * Log of AutoCVS events.
 * @author David Hovemeyer
 */
public class EventLog {
	private List eventList = new LinkedList();
	private List listenerList = new LinkedList();
	
	public interface Listener {
		public void logEvent(Event event);
	}
	
	public synchronized void addListener(Listener listener) {
		listenerList.add(listener);
	}

	public synchronized List getAllEvents() {
		List result = new LinkedList();
		result.addAll(eventList);
		return result;
	}
	
	/**
	 * Notify listeners of an event.
	 * @param event the event
	 */
	private void notifyListeners(Event event) {
		for (Iterator iter = listenerList.iterator(); iter.hasNext();) {
			Listener element = (Listener) iter.next();
			element.logEvent(event);
		}
	}

	public synchronized void purge(){
		eventList.clear();
	}

	/**
	 * Log an event.
	 * @param event the event
	 */
	public void logEvent(Event event) {
		eventList.add(event);
		notifyListeners(event);
		Debug.print(event.getMessage(), event.getException());
	}
	
	/**
	 * Log an error event.
	 * @param event the error event
	 */
	public synchronized void logError(Event event) {
		event.setIsError(true);
		logEvent(event);
	}
	
	/**
	 * Convenience function for logging an informative (non-error) messge.
	 * @param message the message
	 */
	public void logMessage(String message) {
		logEvent(new Event(message));
	}

	/**
	 * Convenience function for logging an error message.
	 * @param message the message
	 */
	public void logError(String message) {
		logError(new Event(message));
	}
	
	/**
	 * Convenience function for logging an exception.
	 * @param message the message
	 * @param e the exception
	 */
	public void logError(String message, Throwable e) {
		logError(new Event(message, e));
	}
}
