/*
 * Created on Jan 22, 2004
 */
package edu.umd.cs.daveho.eclipse.autocvs;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.swt.widgets.List;
import org.eclipse.swt.widgets.Shell;

/**
 * Dialog to submit a project by creating a new submission tag.
 * @author David Hovemeyer
 */
public class SubmitDialog extends Dialog {
	
	// Fields
	private AutoCVSTagSet tagSet;
	private List projectList;
	private int[] openProjectList;
	private int result;

	/**
	 * Constructor.
	 * @param parentShell the parent window
	 * @param tagSet tag set for the project
	 */
	public SubmitDialog(Shell parentShell, AutoCVSTagSet tagSet) {
		super(parentShell);
		this.tagSet = tagSet;
		openProjectList = tagSet.getOpenProjects();
		this.result = -1;
	}
	
	/**
	 * Return the result.  If greater than or equal to zero,
	 * it indicates the number of the project that the user
	 * has chosen to submit.
	 * @return the number of the project to submit, or -1 if no project was chosen
	 */
	public int getResult() {
		return result;
	}
	
	/**
	 * Configure the Shell used to display the dialog.
	 * We use the opportunity to set the title.
	 */
	protected void configureShell(Shell newShell) {
		newShell.setText("Submit project");
		super.configureShell(newShell);
	}

	protected Control createDialogArea(Composite parent) {
		final int WIDTH_HINT = 350;
		final int HEIGHT_HINT = 110;
		
		Layout parentLayout = parent.getLayout();
		
		Composite control = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		layout.numColumns = 1;
		control.setLayout(layout);
		
		int numOpenProjects = openProjectList.length;
		
		if (numOpenProjects == 0) {
			// No projects available.
			Label label = new Label(control, SWT.NONE);
			label.setText("No projects are open for submission");
			GridData gridData = new GridData();
			gridData.widthHint = WIDTH_HINT;
			gridData.heightHint = HEIGHT_HINT;
			label.setLayoutData(gridData);
		} else if (numOpenProjects == 1) {
			// One project available.
			// This should be the usual case.
			Label label = new Label(control, SWT.NONE);
			label.setText("Click 'OK' to submit project " + openProjectList[0]);
			GridData gridData = new GridData();
			gridData.widthHint = WIDTH_HINT;
			gridData.heightHint = HEIGHT_HINT;
			label.setLayoutData(gridData);
		} else {
			// Multiple projects are available for submission:
			// use a list to choose between them.
			
			Label label = new Label(control, SWT.WRAP);
			label.setText("Select the project to submit:");
			
			projectList = new List(control, SWT.SINGLE | SWT.BORDER);
			for (int i = 0; i < openProjectList.length; i++) {
				projectList.add("Project " + openProjectList[i]);
			}
			GridData gridData = new GridData();
			gridData.widthHint = WIDTH_HINT;
			gridData.heightHint = HEIGHT_HINT;
			gridData.grabExcessHorizontalSpace = true;
			projectList.setLayoutData(gridData);
		}

		return control;
	}
	
	protected void buttonPressed(int buttonId) {
		switch (buttonId) {
		case IDialogConstants.OK_ID:
			// Find out which project was selected (if any)
			int selectedProject = -1;
			
			if (openProjectList.length == 1) {
				// Only one project available
				selectedProject = openProjectList[0];
			} else if (openProjectList.length > 1) {
				// Multiple projects available:
				// get selection from List control.
				int index = projectList.getSelectionIndex();
				if (index >= 0 || index < openProjectList.length) {
					Debug.print("Submit project " + openProjectList[index]);
					selectedProject = openProjectList[index];
				}
			}
			result = selectedProject;
			okPressed();
			break;
			
		case IDialogConstants.CANCEL_ID:
			cancelPressed();
			break;
			
		default:
			super.buttonPressed(buttonId);
			break;
		}
	}

}
